
# Slot: has zygosity




URI: [biolink:has_zygosity](https://w3id.org/biolink/vocab/has_zygosity)


## Domain and Range

[GenomicEntity](GenomicEntity.md) &#8594;  <sub>0..1</sub> [Zygosity](Zygosity.md)

## Parents

 *  is_a: [node property](node_property.md)

## Children


## Used by

 * [Genotype](Genotype.md)
